'''
    file package to deal with the file problems
    currently , it contain one py :
    get_filename.py, it obtain get_One_File (choose to obtain file path)、get_Folder(choose to obtain folder path) functions
    ...to be updated
'''