# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-15 15:19:08
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-18 08:39:10
'''
ultilize the tensorflow library to deal with the problem in the question
contains:
	1. ty.py, which contain the main func, like BN、fully-Connected、CNN etc... to be updateds
	2. ...to be updated
'''
