'''
    cv package for deal with the computer vision
    current the package obtain :
        1. CreateVideo.py contain video_display function, input a path create a video display
        2. Image.py contain read_img, write_img functions currently.
        ... to be updated
'''