# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-15 15:19:08
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-16 08:56:51
'''
Gx is a scavenger s` life code. can be summarize as these:

1. cv package , which are used to deal with computer vision
2. file package , which are used to deal with file、folder and others operating system
3. np package , which are used to deal with array in numpy
4. time package , which are used to deal with the time
'''
