# -*- coding: utf-8 -*-
# @Author: Gx
# @Date:   2019-04-15 15:10:25
# @Last Modified by:   Administrator
# @Last Modified time: 2019-04-18 08:51:19
#!/usr/bin/env python
# coding=utf-8

from setuptools import setup, find_packages
'Mylife code'
setup(
    name='Gx',
    version='1.0.3',
    description=(
        'A Scavenger `s code in his whole life'
    ),
    long_description=('A Scavenger in his hometown\n 大风起兮云飞扬\n威加海内兮归故乡\n安得猛士兮守四方 '),
    author='WRQ',
    author_email='wrq2149678246@qq.com',
    maintainer='wrq,',
    maintainer_email='wrq2149678246@qq.com',
    license='BSD License',
    packages=find_packages(),
    platforms=["all"],
    url='',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
)